opennms-client
==============

.. image:: https://travis-ci.org/mvillarejo/opennms-client.png?branch=master
        :target: https://travis-ci.org/mvillarejo/opennms-client

opennms-client is a simple package to manage openNMS.

Usage
(TBC)

License
MIT License
